@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# WZRY · 农活自动化助手
+# autowzry · 自动化农活演示
 # Copyright (C) 2025 cndaqiang
 #
 # This program is free software: you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 # Author : cndaqiang             #
 # Update : 2024-12-08            #
 # Build  : 2024-07-28            #
-# What   : 王者营地的礼包         #
+# What   : WZYD的礼包         #
 ##################################
 import sys
 import os
@@ -69,7 +69,7 @@ class wzyd_libao:
         self.房主 = self.mynode == 0 or self.totalnode == 1
         # prefix, 还用于创建读取一些特定的控制文件/代码
         # prefix, 用于区分不同进程的字典文件中的图片位置，因为不同账户的位置可能又差异
-        self.prefix = "王者营地"+f".{Settings.mynode}"
+        self.prefix = "WZYD"+f".{Settings.mynode}"
         #
         self.设备类型 = self.移动端.设备类型
         self.IOS = "ios" in self.设备类型
@@ -380,7 +380,7 @@ class wzyd_libao:
             # savepos 如果找到会自动替换上一次的字典
             存在, 资讯入口图标 = self.Tool.存在任一张图(资讯入口图标, "资讯入口图标", savepos=True)
             if not 存在:
-                TimeECHO(f"王者营地: 资讯入口图标")
+                TimeECHO(f"WZYD: 资讯入口图标")
                 TimeECHO(f"按照960x540的分辨率强制设定坐标")
                 # 这里是绝对坐标，不适用于其他分辨率的情况
                 self.Tool.var_dict["资讯入口图标"] = (250, 650)
@@ -643,9 +643,9 @@ class wzyd_libao:
         # 每日签到
         self.APPOB.重启APP(10)
         sleep(10)
-        self.Tool.existsTHENtouch(self.个人界面图标, "王者营地个人界面", savepos=True)
+        self.Tool.existsTHENtouch(self.个人界面图标, "WZYD个人界面", savepos=True)
         sleep(5)
-        if not self.Tool.existsTHENtouch(self.每日福利图标, "王者营地每日福利", savepos=False):
+        if not self.Tool.existsTHENtouch(self.每日福利图标, "WZYD每日福利", savepos=False):
             return self.每日签到任务(times)
         sleep(5)
         self.Tool.existsTHENtouch(self.一键领取按钮, "一键领取按钮")
